[![Join the chat at https://gitter.im/lig/mnj](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/lig/mnj?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/lig/mnj.svg?branch=develop)](https://travis-ci.org/lig/mnj)
[![Coverage Status](https://coveralls.io/repos/github/lig/mnj/badge.svg?branch=develop)](https://coveralls.io/github/lig/mnj?branch=develop)
[![Code Health](https://landscape.io/github/lig/mnj/develop/landscape.svg?style=flat)](https://landscape.io/github/lig/mnj/develop)

# Mnj

![Mnj Logo](logo150.png)

**Mnj** (_Mongo Energy_) is a helper library to simplify PyMongo interaction

## Install
Install from PyPI

    pip install mnj

or clone this repository to get the latest source and invoke install

    python setup.py install

## Features
* Using `mnj.q` object for constructing queries will help to validate them.
* No creepy `'$op'` strings any more use `op_()` style operators.

Read the [Mnj Docs](http://mnj.readthedocs.io/) to find out more. 
